==> boduch-0.1.7.tar.gz: boduch-0.1.7/src/boduch/handle/__init__.py <==
#boduch - Simple Python tool library.
#   Copyright (C) 2008  Adam Boduch
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""This package contains basic event handlers."""

from boduch.event import subscribe, EventSetPush, EventSetSet, EventSetSort,\
                         EventSetPop, EventSetGet, EventHashPush,\
                         EventHashPop, EventHashGet, EventEqual, EventGreater,\
                         EventLesser, EventStateMachineAddState,\
                         EventStateMachineAddTransition,\
                         EventStateMachineRemoveState,\
                         EventStateMachineChangeState,\
                         EventStateMachineTransition,\
                         EventStateTransitionTransition
from boduch.handle.handle import Handle
from boduch.handle.data import HandleHashPush, HandleHashPop, HandleHashGet,\
                               HandleSetPush, HandleSetSet, HandleSetSort,\
                               HandleSetPop, HandleSetGet
from boduch.handle.predicate import HandleEqual, HandleGreater, HandleLesser
from boduch.handle.state import HandleStateTransitionTransition,\
                                HandleStateMachineAddState,\
                                HandleStateMachineAddTransition,\
                                HandleStateMachineRemoveState,\
                                HandleStateMachineChangeState,\
                                HandleStateMachineTransition

subscribe(EventSetPush, HandleSetPush)
subscribe(EventSetSet, HandleSetSet)
subscribe(EventSetSort, HandleSetSort)
subscribe(EventSetPop, HandleSetPop)
subscribe(EventSetGet, HandleSetGet)
subscribe(EventHashPush, HandleHashPush)
subscribe(EventHashPop, HandleHashPop)
subscribe(EventHashGet, HandleHashGet)
subscribe(EventEqual, HandleEqual)
subscribe(EventGreater, HandleGreater)
subscribe(EventLesser, HandleLesser)
subscribe(EventStateMachineAddState, HandleStateMachineAddState)
subscribe(EventStateMachineAddTransition, HandleStateMachineAddTransition)
subscribe(EventStateMachineRemoveState, HandleStateMachineRemoveState)
subscribe(EventStateMachineChangeState, HandleStateMachineChangeState)
subscribe(EventStateMachineTransition, HandleStateMachineTransition)
subscribe(EventStateTransitionTransition, HandleStateTransitionTransition)

__all__=['Handle', 'HandleSetPush', 'HandleSetSet', 'HandleSetSort',\
         'HandleSetPop', 'HandleSetGet', 'HandleHashPush', 'HandleHashPop',\
         'HandleHashGet', 'HandleEqual', 'HandleGreater', 'HandleLesser',\
         'HandleStateMachineAddState', 'HandleStateMachineAddTransition',\
         'HandleStateMachineRemoveState', 'HandleStateMachineChangeState',\
         'HandleStateMachineTransition', 'HandleStateTransitionTransition']

==> boduch-0.2.0.tar.gz: boduch-0.2.0/src/boduch/handle/__init__.py <==
#boduch - Simple Python tool library.
#   Copyright (C) 2008  Adam Boduch
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""This package contains basic event handlers."""

from boduch.handle.handle import Handle
from boduch.handle.data import HandleHashPush, HandleHashPop, HandleHashGet,\
                               HandleSetPush, HandleSetSet, HandleSetSort,\
                               HandleSetPop, HandleSetGet
from boduch.handle.predicate import HandleEqual, HandleGreater, HandleLesser
from boduch.handle.state import HandleStateTransitionTransition,\
                                HandleStateMachineAddState,\
                                HandleStateMachineAddTransition,\
                                HandleStateMachineRemoveState,\
                                HandleStateMachineChangeState,\
                                HandleStateMachineTransition,\
                                HandleStateMachineEqual,\
                                HandleStateMachineNotEqual

__all__=['Handle', 'HandleSetPush', 'HandleSetSet', 'HandleSetSort',\
         'HandleSetPop', 'HandleSetGet', 'HandleHashPush', 'HandleHashPop',\
         'HandleHashGet', 'HandleEqual', 'HandleGreater', 'HandleLesser',\
         'HandleStateMachineAddState', 'HandleStateMachineAddTransition',\
         'HandleStateMachineRemoveState', 'HandleStateMachineChangeState',\
         'HandleStateMachineTransition', 'HandleStateMachineEqual',\
         'HandleStateMachineNotEqual', 'HandleStateTransitionTransition']
